@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018 - 2019, Stephan Mueller <smueller@chronox.de>
+ * Copyright (C) 2018 - 2020, Stephan Mueller <smueller@chronox.de>
  *
  * License: see LICENSE file
  *
@@ -26,7 +26,7 @@
 
 #define ECDH_DEF_CALLBACK(name, flags)	DEF_CALLBACK(ecdh, name, flags)
 
-struct ecdh_backend *ecdh_backend = NULL;
+static struct ecdh_backend *ecdh_backend = NULL;
 
 static int ecdh_tester(struct json_object *in, struct json_object *out,
 		      uint64_t cipher)
